'use client';

import { useState, useEffect } from 'react';
import Link from 'next/link';
import { VoteOptionConfig } from '@/lib/survey';

// Define a more flexible stats interface
interface Stats {
  total: number;
  [key: string]: number; // Allow any string keys for dynamic vote options
}

export default function PublicResultsPage() {
  const [stats, setStats] = useState<Stats | null>(null);
  const [voteOptions, setVoteOptions] = useState<VoteOptionConfig[]>([]);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  // Fetch vote options
  useEffect(() => {
    const fetchVoteOptions = async () => {
      try {
        const response = await fetch('/api/editable-text');
        if (response.ok) {
          const data = await response.json();
          if (data.texts && Array.isArray(data.texts)) {
            const voteOptionsEntry = data.texts.find((text: { id: string }) => text.id === 'vote-options');
            if (voteOptionsEntry && Array.isArray(voteOptionsEntry.content)) {
              setVoteOptions(voteOptionsEntry.content);
            }
          }
        }
      } catch (error) {
        console.error('Error fetching vote options:', error);
        // Use default options if fetch fails
        setVoteOptions([
          { id: 'yes', label: 'Ja' },
          { id: 'no', label: 'Nein' },
          { id: 'abstain', label: 'Enthaltung' }
        ]);
      }
    };

    fetchVoteOptions();
  }, []);

  useEffect(() => {
    const fetchStats = async () => {
      try {
        const response = await fetch('/api/public-stats');

        if (!response.ok) {
          throw new Error('Fehler beim Abrufen der Statistiken');
        }

        const data = await response.json();
        setStats(data.stats);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
      } finally {
        setIsLoading(false);
      }
    };

    fetchStats();
  }, []);

  if (isLoading) {
    return (
      <div className="container mx-auto px-4 py-8">
        <div className="ssvc-main-content text-center">
          <p>Lade Ergebnisse...</p>
        </div>
      </div>
    );
  }

  if (error) {
    return (
      <div className="container mx-auto px-4 py-8">
        <div className="ssvc-main-content">
          <div className="text-red-500 mb-4">{error}</div>
          <Link href="/" className="ssvc-button inline-block">
            Zurück zur Startseite
          </Link>
        </div>
      </div>
    );
  }

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold text-[#0057a6] mb-4">ABSTIMMUNGSERGEBNISSE</h1>

        <div className="ssvc-main-content">
          <h2 className="text-xl font-bold text-[#0057a6] mb-4">Aktuelle Ergebnisse der Satzungsänderung</h2>

          {stats && voteOptions.length > 0 && (
            <div className="space-y-4">
              <div className={`grid ${voteOptions.length === 1 ? 'grid-cols-1' : voteOptions.length === 2 ? 'grid-cols-2' : 'grid-cols-3'} gap-4`}>
                {voteOptions.map((option) => (
                  <div key={option.id} className="bg-[#e6f0fa] p-4 text-center">
                    <div className="text-2xl font-bold text-[#0057a6]">{stats[option.id] || 0}</div>
                    <div className="text-sm text-[#0057a6]">{option.label}</div>
                  </div>
                ))}
              </div>

              <div className="bg-[#0057a6] p-4 text-center">
                <div className="text-2xl font-bold text-white">{stats.total}</div>
                <div className="text-sm text-white">Gesamtstimmen</div>
              </div>

              {stats.total > 0 && (
                <div className="mt-4">
                  <h3 className="text-lg font-medium text-[#0057a6] mb-2">Ergebnisübersicht</h3>
                  <div className="h-6 bg-gray-200 overflow-hidden">
                    <div className="flex h-full">
                      {voteOptions.map((option, index) => {
                        const percentage = ((stats[option.id] || 0) / stats.total) * 100;
                        // Define colors for different options
                        const colors = [
                          'bg-[#0057a6]', // Blue for first option (usually yes)
                          'bg-red-500',    // Red for second option (usually no)
                          'bg-gray-500'    // Gray for third option (usually abstain)
                        ];
                        // Use a default color for additional options
                        const color = index < colors.length ? colors[index] : 'bg-green-500';

                        return (
                          <div
                            key={option.id}
                            className={`${color} h-full`}
                            style={{ width: `${percentage}%` }}
                          ></div>
                        );
                      })}
                    </div>
                  </div>
                  <div className="flex justify-between text-xs mt-1">
                    {voteOptions.map((option, index) => {
                      const percentage = Math.round(((stats[option.id] || 0) / stats.total) * 100);
                      // Define text colors for different options
                      const textColors = [
                        'text-[#0057a6]', // Blue for first option (usually yes)
                        'text-red-600',    // Red for second option (usually no)
                        'text-gray-600'    // Gray for third option (usually abstain)
                      ];
                      // Use a default color for additional options
                      const textColor = index < textColors.length ? textColors[index] : 'text-green-600';

                      return (
                        <span key={option.id} className={textColor}>
                          {percentage}% {option.label}
                        </span>
                      );
                    })}
                  </div>
                </div>
              )}
            </div>
          )}
        </div>
      </div>
    </div>
  );
}
