import { NextRequest, NextResponse } from 'next/server';
import { generateRandomToken } from '@/lib/auth';
import { verifyMemberCredentials, getSettings } from '@/lib/server-auth';

export async function POST(request: NextRequest) {
  try {
    // Check if member authentication is enabled
    const settings = getSettings();
    if (!settings.memberAuthEnabled) {
      return NextResponse.json(
        { error: 'Mitgliederanmeldung ist derzeit deaktiviert' },
        { status: 403 }
      );
    }

    // Get credentials from request
    const { memberNumber, password } = await request.json();

    if (!memberNumber || !password) {
      return NextResponse.json(
        { error: 'Mitgliedsnummer und Passwort sind erforderlich' },
        { status: 400 }
      );
    }

    // Verify credentials
    const { valid, hasVoted } = verifyMemberCredentials(memberNumber, password);

    if (!valid) {
      return NextResponse.json(
        { error: 'Ungültige Mitgliedsnummer oder Passwort' },
        { status: 401 }
      );
    }

    // Check if member has already voted
    if (hasVoted) {
      return NextResponse.json(
        { error: 'Sie haben bereits abgestimmt' },
        { status: 403 }
      );
    }

    // Generate a token for voting
    const token = await generateRandomToken(memberNumber);

    // Create the voting URL with the token
    const baseUrl = process.env.NEXT_PUBLIC_BASE_URL || request.nextUrl.origin;
    const voteUrl = `${baseUrl}/vote?token=${encodeURIComponent(token)}`;

    // Create response with token cookie
    const response = NextResponse.json({ token, voteUrl });

    // Set the token cookie
    response.cookies.set('vote-token', token, {
      httpOnly: true,
      secure: process.env.NODE_ENV === 'production',
      maxAge: 60 * 60 * 24 * 7, // 7 days
      path: '/',
    });

    return response;
  } catch (error) {
    console.error('Error during member login:', error);
    return NextResponse.json(
      { error: 'Fehler bei der Anmeldung' },
      { status: 500 }
    );
  }
}
