import { checkAdminAuth } from '@/lib/auth';
import { addMember, deleteMember, getMemberCredentials, updateMember } from '@/lib/server-auth';
import { NextRequest, NextResponse } from 'next/server';

export async function GET() {
  try {
    // Check for admin auth
    const isAuthenticated = await checkAdminAuth();
    if (!isAuthenticated) {
      return NextResponse.json(
        { error: 'Unauthorized' },
        { status: 401 }
      );
    }


    // Get all members
    const members = getMemberCredentials();

    // Remove password from response
    const sanitizedMembers = members.map((v) => ({ ...v, password: undefined }));

    return NextResponse.json({ members: sanitizedMembers });
  } catch (error) {
    console.error('Error getting members:', error);
    return NextResponse.json(
      { error: 'Fehler beim Abrufen der Mitglieder' },
      { status: 500 }
    );
  }
}

export async function POST(request: NextRequest) {
  try {
    // Verify admin authentication
    const body = await request.json();
    // Check for admin auth
    const { password } = body;
    const isAuthenticated = await checkAdminAuth(password);
    if (!isAuthenticated) {
      return NextResponse.json(
        { error: 'Unauthorized' },
        { status: 401 }
      );
    }

    // Get the action and data from the request
    const { action, ...data } = body;

    if (!action) {
      return NextResponse.json(
        { error: 'Aktion ist erforderlich' },
        { status: 400 }
      );
    }

    // Handle different actions
    switch (action) {
      case 'add': {
        const { memberNumber, password } = data;

        if (!memberNumber || !password) {
          return NextResponse.json(
            { error: 'Mitgliedsnummer und Passwort sind erforderlich' },
            { status: 400 }
          );
        }

        const success = addMember(memberNumber, password);

        if (!success) {
          return NextResponse.json(
            { error: 'Mitglied existiert bereits' },
            { status: 400 }
          );
        }

        return NextResponse.json({
          success: true,
          message: 'Mitglied erfolgreich hinzugefügt'
        });
      }

      case 'update': {
        const { memberNumber, password, hasVoted } = data;

        if (!memberNumber) {
          return NextResponse.json(
            { error: 'Mitgliedsnummer ist erforderlich' },
            { status: 400 }
          );
        }

        const success = updateMember(memberNumber, {
          password: password || undefined,
          hasVoted: hasVoted !== undefined ? hasVoted : undefined
        });

        if (!success) {
          return NextResponse.json(
            { error: 'Mitglied nicht gefunden' },
            { status: 404 }
          );
        }

        return NextResponse.json({
          success: true,
          message: 'Mitglied erfolgreich aktualisiert'
        });
      }

      case 'delete': {
        const { memberNumber } = data;

        if (!memberNumber) {
          return NextResponse.json(
            { error: 'Mitgliedsnummer ist erforderlich' },
            { status: 400 }
          );
        }

        const success = deleteMember(memberNumber);

        if (!success) {
          return NextResponse.json(
            { error: 'Mitglied nicht gefunden' },
            { status: 404 }
          );
        }

        return NextResponse.json({
          success: true,
          message: 'Mitglied erfolgreich gelöscht'
        });
      }

      case 'deleteAll': {
        // Get all members
        const members = getMemberCredentials();

        // Delete each member
        for (const member of members) {
          deleteMember(member.memberNumber);
        }

        return NextResponse.json({
          success: true,
          message: 'Alle Mitglieder erfolgreich gelöscht'
        });
      }

      default:
        return NextResponse.json(
          { error: 'Ungültige Aktion' },
          { status: 400 }
        );
    }
  } catch (error) {
    console.error('Error managing members:', error);
    return NextResponse.json(
      { error: 'Fehler bei der Mitgliederverwaltung' },
      { status: 500 }
    );
  }
}
