'use client';

import { useState } from 'react';
import MembersManager from '@/components/MembersManager';

interface MemberAuthManagerProps {
    memberAuthEnabled: boolean;
    onMemberAuthChange: (enabled: boolean) => void;
}

export default function MemberAuthManager({ memberAuthEnabled, onMemberAuthChange }: MemberAuthManagerProps) {
    const [showMembers, setShowMembers] = useState(false);
    const [isTogglingMemberAuth, setIsTogglingMemberAuth] = useState(false);
    const [error, setError] = useState<string | null>(null);

    const handleToggleMemberAuth = async () => {
        setIsTogglingMemberAuth(true);
        setError(null);

        try {
            const response = await fetch('/api/toggle-member-auth', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({}),
            });

            const data = await response.json();

            if (!response.ok) {
                throw new Error(data.error || 'Fehler beim Ändern der Einstellung');
            }

            onMemberAuthChange(data.memberAuthEnabled);

            // Show success message
            alert(data.message);
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsTogglingMemberAuth(false);
        }
    };

    return (
        <div className="mb-6">
            <div className="flex justify-between items-center mb-4">
                <h2 className="text-xl font-bold text-[#0057a6]">Mitgliederanmeldung</h2>
                <button
                    onClick={handleToggleMemberAuth}
                    disabled={isTogglingMemberAuth}
                    className={`px-3 py-1 rounded text-white ${memberAuthEnabled
                        ? 'bg-green-600 hover:bg-green-700'
                        : 'bg-gray-600 hover:bg-gray-700'
                        }`}
                >
                    {isTogglingMemberAuth
                        ? 'Wird geändert...'
                        : memberAuthEnabled
                            ? 'Aktiviert'
                            : 'Deaktiviert'}
                </button>
            </div>

            <div className="p-4 bg-[#e6f0fa] mb-4">
                <p className="mb-3">
                    Mit dieser Funktion können sich Mitglieder mit ihrer Mitgliedsnummer und einem Passwort anmelden, um abzustimmen.
                </p>

                {error && (
                    <div className="text-red-500 text-sm mb-3">{error}</div>
                )}

                <div className="flex gap-2">
                    <button
                        onClick={() => setShowMembers(!showMembers)}
                        className="ssvc-button flex-1"
                    >
                        {showMembers ? 'Mitgliederverwaltung ausblenden' : 'Mitgliederverwaltung anzeigen'}
                    </button>
                </div>
            </div>

            {showMembers && (
                <div className="mb-6">
                    <MembersManager />
                </div>
            )}
        </div>
    );
}
