'use client';

import { useState } from 'react';

interface ResetVotesProps {
    onReset?: () => void;
}

export default function ResetVotes({ onReset }: ResetVotesProps) {
    const [isResetting, setIsResetting] = useState(false);
    const [error, setError] = useState<string | null>(null);

    const handleResetVotes = async () => {
        // Show confirmation dialog
        if (!confirm('Sind Sie sicher, dass Sie alle Abstimmungsdaten zurücksetzen möchten? Diese Aktion kann nicht rückgängig gemacht werden.')) {
            return;
        }

        setIsResetting(true);
        setError(null);

        try {
            const response = await fetch('/api/reset-votes', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({}), // No need to send password, using JWT cookie
            });

            const data = await response.json();

            if (!response.ok) {
                throw new Error(data.error || 'Fehler beim Zurücksetzen der Abstimmungsdaten');
            }

            // Show success message
            alert('Abstimmungsdaten wurden erfolgreich zurückgesetzt.');

            // Call the onReset callback if provided
            if (onReset) {
                onReset();
            }
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsResetting(false);
        }
    };

    return (
        <div className="mb-6">
            <h2 className="text-xl font-bold text-[#0057a6] mb-4">Zur&uuml;cksetzen</h2>

            <div className="mb-4">
                <button
                    onClick={handleResetVotes}
                    disabled={isResetting}
                    className="w-full bg-red-600 hover:bg-red-700 text-white font-medium py-2 px-4 transition-colors duration-300 disabled:opacity-50"
                >
                    {isResetting ? 'Zurücksetzen...' : 'Abstimmungsdaten zurücksetzen'}
                </button>
                <p className="text-xs text-gray-600 mt-1">
                    Achtung: Diese Aktion löscht alle Abstimmungsdaten und kann nicht rückgängig gemacht werden.
                </p>
            </div>

            {error && (
                <div className="text-red-500 text-sm mb-4">{error}</div>
            )}
        </div>
    );
}
