'use client';

import { useState } from 'react';
import { VoteOption } from '@/lib/survey';

// Define types based on the data structure
interface Stats {
    total: number;
    [key: string]: number; // Allow dynamic keys for vote options
}

interface Comment {
    vote: VoteOption;
    comment: string;
    timestamp: string;
}

interface StatsButtonProps {
    onStatsLoaded: (stats: Stats, comments: Comment[]) => void;
}

export default function StatsButton({ onStatsLoaded }: StatsButtonProps) {
    const [isLoading, setIsLoading] = useState(false);
    const [error, setError] = useState<string | null>(null);

    const handleGetStats = async () => {
        setIsLoading(true);
        setError(null);

        try {
            const response = await fetch('/api/stats', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({}), // No need to send password, using JWT cookie
            });

            const data = await response.json();

            if (!response.ok) {
                throw new Error(data.error || 'Statistiken konnten nicht abgerufen werden');
            }

            onStatsLoaded(data.stats, data.comments || []);
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    return (
        <div className="flex gap-2 mb-4">
            <button
                onClick={handleGetStats}
                disabled={isLoading}
                className="flex-1 bg-gray-600 hover:bg-gray-700 text-white font-medium py-2 px-4 transition-colors duration-300 disabled:opacity-50"
            >
                {isLoading ? 'Lade Statistiken...' : 'Statistiken anzeigen'}
            </button>

            {error && (
                <div className="text-red-500 text-sm">{error}</div>
            )}
        </div>
    );
}
