'use client';

import { VoteOption } from '@/lib/survey';

interface Stats {
    total: number;
    [key: string]: number; // Allow dynamic keys for vote options
}

interface Comment {
    vote: VoteOption;
    comment: string;
    timestamp: string;
}

interface StatsDisplayProps {
    stats: Stats;
    comments: Comment[];
    voteOptions: { id: string; label: string }[];
    onBack: () => void;
}

export default function StatsDisplay({ stats, comments, voteOptions, onBack }: StatsDisplayProps) {
    return (
        <div className="ssvc-main-content">
            <h2 className="text-xl font-bold text-[#0057a6] mb-4">Abstimmungsstatistiken</h2>

            {stats && voteOptions.length > 0 && (
                <div className="space-y-4">
                    <div className={`grid ${voteOptions.length === 1 ? 'grid-cols-1' : voteOptions.length === 2 ? 'grid-cols-2' : 'grid-cols-3'} gap-4`}>
                        {voteOptions.map((option) => (
                            <div key={option.id} className="bg-[#e6f0fa] p-4 text-center">
                                <div className="text-2xl font-bold text-[#0057a6]">{stats[option.id] || 0}</div>
                                <div className="text-sm text-[#0057a6]">{option.label}</div>
                            </div>
                        ))}
                    </div>

                    <div className="bg-[#0057a6] p-4 text-center">
                        <div className="text-2xl font-bold text-white">{stats.total}</div>
                        <div className="text-sm text-white">Gesamtstimmen</div>
                    </div>

                    {stats.total > 0 && (
                        <div className="mt-4">
                            <h3 className="text-lg font-medium text-[#0057a6] mb-2">Ergebnisübersicht</h3>
                            <div className="h-6 bg-gray-200 overflow-hidden">
                                <div className="flex h-full">
                                    {voteOptions.map((option, index) => {
                                        const percentage = ((stats[option.id] || 0) / stats.total) * 100;
                                        // Define colors for different options
                                        const colors = [
                                            'bg-[#0057a6]', // Blue for first option (usually yes)
                                            'bg-red-500',    // Red for second option (usually no)
                                            'bg-gray-500'    // Gray for third option (usually abstain)
                                        ];
                                        // Use a default color for additional options
                                        const color = index < colors.length ? colors[index] : 'bg-green-500';

                                        return (
                                            <div
                                                key={option.id}
                                                className={`${color} h-full`}
                                                style={{ width: `${percentage}%` }}
                                            ></div>
                                        );
                                    })}
                                </div>
                            </div>
                            <div className="flex justify-between text-xs mt-1">
                                {voteOptions.map((option, index) => {
                                    const percentage = Math.round(((stats[option.id] || 0) / stats.total) * 100);
                                    // Define text colors for different options
                                    const textColors = [
                                        'text-[#0057a6]', // Blue for first option (usually yes)
                                        'text-red-600',    // Red for second option (usually no)
                                        'text-gray-600'    // Gray for third option (usually abstain)
                                    ];
                                    // Use a default color for additional options
                                    const textColor = index < textColors.length ? textColors[index] : 'text-green-600';

                                    return (
                                        <span key={option.id} className={textColor}>
                                            {percentage}% {option.label}
                                        </span>
                                    );
                                })}
                            </div>
                        </div>
                    )}
                </div>
            )}

            {comments.length > 0 && (
                <div className="mt-8">
                    <h3 className="text-lg font-medium text-[#0057a6] mb-4">Kommentare der Teilnehmer</h3>
                    <div className="space-y-4">
                        {comments.map((comment, index) => (
                            <div key={index} className="p-4 bg-[#e6f0fa] rounded">
                                <div className="flex justify-between items-center mb-2">
                                    <span className="font-medium">
                                        {voteOptions.find(option => option.id === comment.vote)?.label || comment.vote}
                                    </span>
                                    <span className="text-xs text-gray-500">
                                        {new Date(comment.timestamp).toLocaleDateString('de-DE')}
                                    </span>
                                </div>
                                <p className="text-gray-700">{comment.comment}</p>
                            </div>
                        ))}
                    </div>
                </div>
            )}

            <button
                onClick={onBack}
                className="ssvc-button mt-4"
            >
                Zurück zum Link-Generator
            </button>
        </div>
    );
}
