'use client';

import { useState } from 'react';

interface VoteOptionsManagerProps {
    voteOptions: { id: string; label: string }[];
    onVoteOptionsChange: (newOptions: { id: string; label: string }[]) => void;
}

export default function VoteOptionsManager({ voteOptions, onVoteOptionsChange }: VoteOptionsManagerProps) {
    const [showVoteOptions, setShowVoteOptions] = useState(false);
    const [newOptionId, setNewOptionId] = useState('');
    const [newOptionLabel, setNewOptionLabel] = useState('');
    const [isLoading, setIsLoading] = useState(false);
    const [error, setError] = useState<string | null>(null);

    // Add a new vote option
    const handleAddVoteOption = async () => {
        if (!newOptionId || !newOptionLabel) {
            setError('Bitte geben Sie sowohl eine ID als auch ein Label für die neue Option ein');
            return;
        }

        // Check if ID already exists
        if (voteOptions.some(option => option.id === newOptionId)) {
            setError('Eine Option mit dieser ID existiert bereits');
            return;
        }

        setIsLoading(true);
        setError(null);

        try {
            // Add to local state
            const updatedOptions = [...voteOptions, { id: newOptionId, label: newOptionLabel }];

            // Save to server
            const response = await fetch('/api/editable-text', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    id: 'vote-options',
                    content: updatedOptions
                }),
            });

            if (!response.ok) {
                throw new Error('Fehler beim Speichern der Abstimmungsoptionen');
            }

            // Update parent component state
            onVoteOptionsChange(updatedOptions);

            // Reset form
            setNewOptionId('');
            setNewOptionLabel('');
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    // Remove a vote option
    const handleRemoveVoteOption = async (optionId: string) => {
        // Don't allow removing if there are less than 2 options
        if (voteOptions.length <= 1) {
            setError('Es muss mindestens eine Abstimmungsoption vorhanden sein');
            return;
        }

        // Show confirmation dialog
        if (!confirm(`Sind Sie sicher, dass Sie die Option "${optionId}" entfernen möchten? Bestehende Abstimmungen mit dieser Option werden nicht gelöscht, aber in den Statistiken möglicherweise nicht mehr korrekt angezeigt.`)) {
            return;
        }

        setIsLoading(true);
        setError(null);

        try {
            // Remove from local state
            const updatedOptions = voteOptions.filter(option => option.id !== optionId);

            // Save to server
            const response = await fetch('/api/editable-text', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    id: 'vote-options',
                    content: updatedOptions
                }),
            });

            if (!response.ok) {
                throw new Error('Fehler beim Speichern der Abstimmungsoptionen');
            }

            // Update parent component state
            onVoteOptionsChange(updatedOptions);
        } catch (err) {
            setError(err instanceof Error ? err.message : 'Ein Fehler ist aufgetreten');
        } finally {
            setIsLoading(false);
        }
    };

    return (
        <div className="mb-6">
            <div className="flex justify-between items-center mb-4">
                <h2 className="text-xl font-bold text-[#0057a6]">Abstimmungsoptionen</h2>
                <button
                    onClick={() => setShowVoteOptions(!showVoteOptions)}
                    className="text-sm text-[#0057a6] hover:underline"
                >
                    {showVoteOptions ? 'Ausblenden' : 'Bearbeiten'}
                </button>
            </div>

            {showVoteOptions && (
                <div className="bg-[#e6f0fa] p-4 mb-4">
                    <h3 className="font-medium text-[#0057a6] mb-3">Aktuelle Optionen</h3>

                    <div className="space-y-2 mb-4">
                        {voteOptions.map((option) => (
                            <div key={option.id} className="flex items-center justify-between p-2 bg-white">
                                <div>
                                    <span className="font-medium">{option.id}:</span> {option.label}
                                </div>
                                <button
                                    onClick={() => handleRemoveVoteOption(option.id)}
                                    className="text-red-600 hover:text-red-800"
                                    title="Option entfernen"
                                >
                                    ✕
                                </button>
                            </div>
                        ))}
                    </div>

                    <h3 className="font-medium text-[#0057a6] mb-2">Neue Option hinzufügen</h3>
                    <div className="space-y-3">
                        <div>
                            <label htmlFor="newOptionId" className="block text-sm font-medium text-gray-700 mb-1">
                                Option ID (z.B. &quot;yes&quot;, &quot;no&quot;)
                            </label>
                            <input
                                type="text"
                                id="newOptionId"
                                value={newOptionId}
                                onChange={(e) => setNewOptionId(e.target.value)}
                                className="w-full px-3 py-2 border border-gray-300 focus:outline-none focus:border-[#0057a6]"
                                placeholder="option-id"
                            />
                            <p className="text-xs text-gray-500 mt-1">
                                Die ID wird intern verwendet und sollte kurz und eindeutig sein.
                            </p>
                        </div>

                        <div>
                            <label htmlFor="newOptionLabel" className="block text-sm font-medium text-gray-700 mb-1">
                                Anzeigename
                            </label>
                            <input
                                type="text"
                                id="newOptionLabel"
                                value={newOptionLabel}
                                onChange={(e) => setNewOptionLabel(e.target.value)}
                                className="w-full px-3 py-2 border border-gray-300 focus:outline-none focus:border-[#0057a6]"
                                placeholder="Anzeigename der Option"
                            />
                            <p className="text-xs text-gray-500 mt-1">
                                Der Anzeigename wird den Abstimmenden angezeigt.
                            </p>
                        </div>

                        {error && (
                            <div className="text-red-500 text-sm">{error}</div>
                        )}

                        <button
                            onClick={handleAddVoteOption}
                            disabled={isLoading}
                            className="ssvc-button w-full disabled:opacity-50"
                        >
                            {isLoading ? 'Wird hinzugefügt...' : 'Option hinzufügen'}
                        </button>
                    </div>

                    <div className="mt-4 text-sm text-gray-600">
                        <p className="font-medium">Hinweis:</p>
                        <p>Das Ändern der Abstimmungsoptionen wirkt sich nur auf neue Abstimmungen aus. Bestehende Abstimmungsdaten bleiben unverändert.</p>
                    </div>
                </div>
            )}
        </div>
    );
}
